@@ -1,5 +1,5 @@
 import json
-from typing import Dict, Tuple, Union
+from typing import Union
 
 from moto.core.responses import BaseResponse
 
@@ -14,7 +14,7 @@ class AthenaResponse(BaseResponse):
     def athena_backend(self) -> AthenaBackend:
         return athena_backends[self.current_account][self.region]
 
-    def create_work_group(self) -> Union[Tuple[str, Dict[str, int]], str]:
+    def create_work_group(self) -> Union[tuple[str, dict[str, int]], str]:
         name = self._get_param("Name")
         description = self._get_param("Description")
         configuration = self._get_param("Configuration")
@@ -46,7 +46,7 @@ class AthenaResponse(BaseResponse):
         self.athena_backend.delete_work_group(name)
         return "{}"
 
-    def start_query_execution(self) -> Union[Tuple[str, Dict[str, int]], str]:
+    def start_query_execution(self) -> Union[tuple[str, dict[str, int]], str]:
         query = self._get_param("QueryString")
         context = self._get_param("QueryExecutionContext")
         config = self._get_param("ResultConfiguration")
@@ -76,18 +76,24 @@ class AthenaResponse(BaseResponse):
                 "Query": execution.query,
                 "StatementType": statement_type,
                 "ResultConfiguration": execution.config,
+                "ResultReuseConfiguration": {
+                    "ResultReuseByAgeConfiguration": {"Enabled": False}
+                },
                 "QueryExecutionContext": execution.context,
                 "Status": {
                     "State": execution.status,
                     "SubmissionDateTime": execution.start_time,
+                    "CompletionDateTime": execution.end_time,
                 },
                 "Statistics": {
                     "EngineExecutionTimeInMillis": 0,
                     "DataScannedInBytes": 0,
                     "TotalExecutionTimeInMillis": 0,
                     "QueryQueueTimeInMillis": 0,
+                    "ServicePreProcessingTimeInMillis": 0,
                     "QueryPlanningTimeInMillis": 0,
                     "ServiceProcessingTimeInMillis": 0,
+                    "ResultReuseInformation": {"ReusedPreviousResult": False},
                 },
                 "WorkGroup": execution.workgroup.name if execution.workgroup else None,
             }
@@ -98,6 +104,38 @@ class AthenaResponse(BaseResponse):
             )
         return json.dumps(result)
 
+    def create_capacity_reservation(self) -> Union[tuple[str, dict[str, int]], str]:
+        name = self._get_param("Name")
+        target_dpus = self._get_param("TargetDpus")
+        tags = self._get_param("Tags")
+        self.athena_backend.create_capacity_reservation(name, target_dpus, tags)
+        return json.dumps({})
+
+    def get_capacity_reservation(self) -> Union[str, tuple[str, dict[str, int]]]:
+        name = self._get_param("Name")
+        capacity_reservation = self.athena_backend.get_capacity_reservation(name)
+        if not capacity_reservation:
+            return self.error("Capacity reservation does not exist", 400)
+        return json.dumps(
+            {
+                "CapacityReservation": {
+                    "Name": capacity_reservation.name,
+                    "TargetDpus": capacity_reservation.target_dpus,
+                    "Tags": capacity_reservation.tags,
+                }
+            }
+        )
+
+    def list_capacity_reservations(self) -> str:
+        capacity_reservations = self.athena_backend.list_capacity_reservations()
+        return json.dumps({"CapacityReservations": capacity_reservations})
+
+    def update_capacity_reservation(self) -> str:
+        name = self._get_param("Name")
+        target_dpus = self._get_param("TargetDpus")
+        self.athena_backend.update_capacity_reservation(name, target_dpus)
+        return "{}"
+
     def get_query_results(self) -> str:
         exec_id = self._get_param("QueryExecutionId")
         result = self.athena_backend.get_query_results(exec_id)
@@ -106,20 +144,20 @@ class AthenaResponse(BaseResponse):
     def list_query_executions(self) -> str:
         workgroup = self._get_param("WorkGroup")
         executions = self.athena_backend.list_query_executions(workgroup)
-        return json.dumps({"QueryExecutionIds": [i for i in executions.keys()]})
+        return json.dumps({"QueryExecutionIds": list(executions.keys())})
 
     def stop_query_execution(self) -> str:
         exec_id = self._get_param("QueryExecutionId")
         self.athena_backend.stop_query_execution(exec_id)
         return json.dumps({})
 
-    def error(self, msg: str, status: int) -> Tuple[str, Dict[str, int]]:
+    def error(self, msg: str, status: int) -> tuple[str, dict[str, int]]:
         return (
             json.dumps({"__type": "InvalidRequestException", "Message": msg}),
-            dict(status=status),
+            {"status": status},
         )
 
-    def create_named_query(self) -> Union[Tuple[str, Dict[str, int]], str]:
+    def create_named_query(self) -> Union[tuple[str, dict[str, int]], str]:
         name = self._get_param("Name")
         description = self._get_param("Description")
         database = self._get_param("Database")
@@ -153,11 +191,18 @@ class AthenaResponse(BaseResponse):
             {"DataCatalogsSummary": self.athena_backend.list_data_catalogs()}
         )
 
+    def list_tags_for_resource(self) -> Union[tuple[str, dict[str, int]], str]:
+        resource_arn = self._get_param("ResourceARN")
+        tags = self.athena_backend.list_tags_for_resource(resource_arn)
+        if not tags:
+            return self.error(f"Athena Resource, {resource_arn} Does Not Exist", 400)
+        return json.dumps(tags)
+
     def get_data_catalog(self) -> str:
         name = self._get_param("Name")
         return json.dumps({"DataCatalog": self.athena_backend.get_data_catalog(name)})
 
-    def create_data_catalog(self) -> Union[Tuple[str, Dict[str, int]], str]:
+    def create_data_catalog(self) -> Union[tuple[str, dict[str, int]], str]:
         name = self._get_param("Name")
         catalog_type = self._get_param("Type")
         description = self._get_param("Description")
@@ -187,7 +232,7 @@ class AthenaResponse(BaseResponse):
         )
         return json.dumps({"NamedQueryIds": named_query_ids, "NextToken": next_token})
 
-    def create_prepared_statement(self) -> Union[str, Tuple[str, Dict[str, int]]]:
+    def create_prepared_statement(self) -> Union[str, tuple[str, dict[str, int]]]:
         statement_name = self._get_param("StatementName")
         work_group = self._get_param("WorkGroup")
         query_statement = self._get_param("QueryStatement")
@@ -200,7 +245,7 @@ class AthenaResponse(BaseResponse):
             query_statement=query_statement,
             description=description,
         )
-        return json.dumps(dict())
+        return json.dumps({})
 
     def get_prepared_statement(self) -> str:
         statement_name = self._get_param("StatementName")
@@ -221,7 +266,7 @@ class AthenaResponse(BaseResponse):
             }
         )
 
-    def get_query_runtime_statistics(self) -> Union[str, Tuple[str, Dict[str, int]]]:
+    def get_query_runtime_statistics(self) -> Union[str, tuple[str, dict[str, int]]]:
         query_execution_id = self._get_param("QueryExecutionId")
 
         ps = self.athena_backend.get_query_runtime_statistics(
