@@ -1,4 +1,4 @@
-from typing import Any, Dict
+from typing import Any
 from urllib.parse import unquote
 
 import xmltodict
@@ -14,13 +14,25 @@ class CloudFrontResponse(BaseResponse):
     def __init__(self) -> None:
         super().__init__(service_name="cloudfront")
 
-    def _get_xml_body(self) -> Dict[str, Any]:
+    def _get_xml_body(self) -> dict[str, Any]:
         return xmltodict.parse(self.body, dict_constructor=dict, force_list="Path")
 
     @property
     def backend(self) -> CloudFrontBackend:
         return cloudfront_backends[self.current_account][self.partition]
 
+    @classmethod
+    def tagging(cls, request: Any, full_url: str, headers: Any) -> TYPE_RESPONSE:  # type: ignore
+        response = cls()
+        response.setup_class(request, full_url, headers)
+        operation = response._get_param("Operation")
+        if operation == "Tag":
+            return 204, {}, response.tag_resource()[2]
+        if operation == "Untag":
+            return 204, {}, response.untag_resource()[2]
+        if request.method == "GET":
+            return 200, {}, response.list_tags_for_resource()[2]
+
     def create_distribution(self) -> TYPE_RESPONSE:
         params = self._get_xml_body()
         if "DistributionConfigWithTags" in params:
@@ -118,6 +130,24 @@ class CloudFrontResponse(BaseResponse):
         response = template.render(tags=tags, xmlns=XMLNS)
         return 200, {}, response
 
+    def tag_resource(self) -> TYPE_RESPONSE:
+        resource = unquote(self._get_param("Resource"))
+        params = self._get_xml_body()
+        tags = params.get("Tags", {}).get("Items", {}).get("Tag", [])
+        if not isinstance(tags, list):
+            tags = [tags]
+        self.backend.tag_resource(resource=resource, tags=tags)
+        return 204, {}, ""
+
+    def untag_resource(self) -> TYPE_RESPONSE:
+        resource = unquote(self._get_param("Resource"))
+        params = self._get_xml_body()
+        tag_keys_data = params.get("TagKeys", {}).get("Items", {}).get("Key", [])
+        if not isinstance(tag_keys_data, list):
+            tag_keys_data = [tag_keys_data]
+        self.backend.untag_resource(resource=resource, tag_keys=tag_keys_data)
+        return 204, {}, ""
+
     def create_origin_access_control(self) -> TYPE_RESPONSE:
         config = self._get_xml_body().get("OriginAccessControlConfig", {})
         config.pop("@xmlns", None)
@@ -324,7 +354,7 @@ DIST_CONFIG_TEMPLATE = """
       <DefaultCacheBehavior>
         <TargetOriginId>{{ distribution.distribution_config.default_cache_behavior.target_origin_id }}</TargetOriginId>
         <TrustedSigners>
-          <Enabled>{{ 'true' if distribution.distribution_config.default_cache_behavior.trusted_signers.acct_nums|length > 0 else 'false' }}</Enabled>          
+          <Enabled>{{ 'true' if distribution.distribution_config.default_cache_behavior.trusted_signers.acct_nums|length > 0 else 'false' }}</Enabled>
           <Quantity>{{ distribution.distribution_config.default_cache_behavior.trusted_signers.acct_nums|length }}</Quantity>
           <Items>
             {% for aws_account_number  in distribution.distribution_config.default_cache_behavior.trusted_signers.acct_nums %}
