@@ -19,7 +19,7 @@ from base64 import b64decode, b64encode
 from datetime import datetime, timezone
 from gzip import GzipFile
 from time import time
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Optional
 
 import requests
 
@@ -37,6 +37,7 @@ from moto.firehose.exceptions import (
 from moto.moto_api._internal import mock_random
 from moto.s3.models import s3_backends
 from moto.utilities.tagging_service import TaggingService
+from moto.utilities.utils import get_partition
 
 MAX_TAGS_PER_DELIVERY_STREAM = 50
 
@@ -46,11 +47,12 @@ DESTINATION_TYPES_TO_NAMES = {
     "http_endpoint": "HttpEndpoint",
     "elasticsearch": "Elasticsearch",
     "redshift": "Redshift",
+    "snowflake": "Snowflake",
     "splunk": "Splunk",  # Unimplemented
 }
 
 
-def find_destination_config_in_args(api_args: Dict[str, Any]) -> Tuple[str, Any]:
+def find_destination_config_in_args(api_args: dict[str, Any]) -> tuple[str, Any]:
     """Return (config_name, config) tuple for destination config.
 
     Determines which destination config(s) have been specified.  The
@@ -84,8 +86,8 @@ def find_destination_config_in_args(api_args: Dict[str, Any]) -> Tuple[str, Any]
 
 
 def create_s3_destination_config(
-    extended_s3_destination_config: Dict[str, Any],
-) -> Dict[str, Any]:
+    extended_s3_destination_config: dict[str, Any],
+) -> dict[str, Any]:
     """Return dict with selected fields copied from ExtendedS3 config.
 
     When an ExtendedS3 config is chosen, AWS tacks on a S3 config as
@@ -106,7 +108,7 @@ def create_s3_destination_config(
     return destination
 
 
-class DeliveryStream(BaseModel):  # pylint: disable=too-few-public-methods,too-many-instance-attributes
+class DeliveryStream(BaseModel):
     """Represents a delivery stream, its source and destination configs."""
 
     STATES = {"CREATING", "ACTIVE", "CREATING_FAILED"}
@@ -126,11 +128,11 @@ class DeliveryStream(BaseModel):  # pylint: disable=too-few-public-methods,too-m
         region: str,
         delivery_stream_name: str,
         delivery_stream_type: str,
-        encryption: Dict[str, Any],
-        kinesis_stream_source_configuration: Dict[str, Any],
+        encryption: dict[str, Any],
+        kinesis_stream_source_configuration: dict[str, Any],
         destination_name: str,
-        destination_config: Dict[str, Any],
-    ):  # pylint: disable=too-many-arguments
+        destination_config: dict[str, Any],
+    ):
         self.delivery_stream_status = "CREATING"
         self.delivery_stream_name = delivery_stream_name
         self.delivery_stream_type = (
@@ -139,7 +141,7 @@ class DeliveryStream(BaseModel):  # pylint: disable=too-few-public-methods,too-m
         self.delivery_stream_encryption_configuration = encryption
 
         self.source = kinesis_stream_source_configuration
-        self.destinations: List[Dict[str, Any]] = [
+        self.destinations: list[dict[str, Any]] = [
             {
                 "destination_id": "destinationId-000000000001",
                 destination_name: destination_config,
@@ -160,7 +162,7 @@ class DeliveryStream(BaseModel):  # pylint: disable=too-few-public-methods,too-m
                 del self.destinations[0][destination_name][old]
 
         self.delivery_stream_status = "ACTIVE"
-        self.delivery_stream_arn = f"arn:aws:firehose:{region}:{account_id}:deliverystream/{delivery_stream_name}"
+        self.delivery_stream_arn = f"arn:{get_partition(region)}:firehose:{region}:{account_id}:deliverystream/{delivery_stream_name}"
 
         self.create_timestamp = datetime.now(timezone.utc).isoformat()
         self.version_id = "1"  # Used to track updates of destination configs
@@ -174,32 +176,33 @@ class FirehoseBackend(BaseBackend):
 
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.delivery_streams: Dict[str, DeliveryStream] = {}
+        self.delivery_streams: dict[str, DeliveryStream] = {}
         self.tagger = TaggingService()
 
     @staticmethod
     def default_vpc_endpoint_service(
-        service_region: str, zones: List[str]
-    ) -> List[Dict[str, str]]:
+        service_region: str, zones: list[str]
+    ) -> list[dict[str, str]]:
         """Default VPC endpoint service."""
         return BaseBackend.default_vpc_endpoint_service_factory(
             service_region, zones, "firehose", special_service_name="kinesis-firehose"
         )
 
-    def create_delivery_stream(  # pylint: disable=unused-argument
+    def create_delivery_stream(
         self,
         region: str,
         delivery_stream_name: str,
         delivery_stream_type: str,
-        kinesis_stream_source_configuration: Dict[str, Any],
-        delivery_stream_encryption_configuration_input: Dict[str, Any],
-        s3_destination_configuration: Dict[str, Any],
-        extended_s3_destination_configuration: Dict[str, Any],
-        redshift_destination_configuration: Dict[str, Any],
-        elasticsearch_destination_configuration: Dict[str, Any],
-        splunk_destination_configuration: Dict[str, Any],
-        http_endpoint_destination_configuration: Dict[str, Any],
-        tags: List[Dict[str, str]],
+        kinesis_stream_source_configuration: dict[str, Any],
+        delivery_stream_encryption_configuration_input: dict[str, Any],
+        s3_destination_configuration: dict[str, Any],
+        extended_s3_destination_configuration: dict[str, Any],
+        redshift_destination_configuration: dict[str, Any],
+        elasticsearch_destination_configuration: dict[str, Any],
+        splunk_destination_configuration: dict[str, Any],
+        http_endpoint_destination_configuration: dict[str, Any],
+        snowflake_destination_configuration: dict[str, Any],
+        tags: list[dict[str, str]],
     ) -> str:
         """Create a Kinesis Data Firehose delivery stream."""
         (destination_name, destination_config) = find_destination_config_in_args(
@@ -221,7 +224,10 @@ class FirehoseBackend(BaseBackend):
 
         # Rule out situations that are not yet implemented.
         if destination_name == "Splunk":
-            warnings.warn("A Splunk destination delivery stream is not yet implemented")
+            warnings.warn(
+                "A Splunk destination delivery stream is not yet implemented",
+                stacklevel=2,
+            )
 
         if (
             kinesis_stream_source_configuration
@@ -280,7 +286,7 @@ class FirehoseBackend(BaseBackend):
         delivery_stream.delivery_stream_status = "DELETING"
         self.delivery_streams.pop(delivery_stream_name)
 
-    def describe_delivery_stream(self, delivery_stream_name: str) -> Dict[str, Any]:
+    def describe_delivery_stream(self, delivery_stream_name: str) -> dict[str, Any]:
         """Return description of specified delivery stream and its status.
 
         Note:  the 'limit' and 'exclusive_start_destination_id' parameters
@@ -293,7 +299,7 @@ class FirehoseBackend(BaseBackend):
                 f"not found."
             )
 
-        result: Dict[str, Any] = {
+        result: dict[str, Any] = {
             "DeliveryStreamDescription": {"HasMoreDestinations": False}
         }
         for attribute, attribute_value in vars(delivery_stream).items():
@@ -335,7 +341,7 @@ class FirehoseBackend(BaseBackend):
         limit: Optional[int],
         delivery_stream_type: str,
         exclusive_start_delivery_stream_name: str,
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         """Return list of delivery streams in alphabetic order of names."""
         result = {"DeliveryStreamNames": [], "HasMoreDeliveryStreams": False}
         if not self.delivery_streams:
@@ -375,7 +381,7 @@ class FirehoseBackend(BaseBackend):
         delivery_stream_name: str,
         exclusive_start_tag_key: str,
         limit: Optional[int],
-    ) -> Dict[str, Any]:
+    ) -> dict[str, Any]:
         """Return list of tags."""
         result = {"Tags": [], "HasMoreTags": False}
         delivery_stream = self.delivery_streams.get(delivery_stream_name)
@@ -403,8 +409,8 @@ class FirehoseBackend(BaseBackend):
         return result
 
     def put_record(
-        self, delivery_stream_name: str, record: Dict[str, bytes]
-    ) -> Dict[str, Any]:
+        self, delivery_stream_name: str, record: dict[str, bytes]
+    ) -> dict[str, Any]:
         """Write a single data record into a Kinesis Data firehose stream."""
         result = self.put_record_batch(delivery_stream_name, [record])
         return {
@@ -414,8 +420,8 @@ class FirehoseBackend(BaseBackend):
 
     @staticmethod
     def put_http_records(  # type: ignore[misc]
-        http_destination: Dict[str, Any], records: List[Dict[str, bytes]]
-    ) -> List[Dict[str, str]]:
+        http_destination: dict[str, Any], records: list[dict[str, bytes]]
+    ) -> list[dict[str, str]]:
         """Put records to a HTTP destination."""
         # Mostly copied from localstack
         url = http_destination["EndpointConfiguration"]["Url"]
@@ -444,7 +450,7 @@ class FirehoseBackend(BaseBackend):
         # Path prefix pattern: myApp/YYYY/MM/DD/HH/
         # Object name pattern:
         # DeliveryStreamName-DeliveryStreamVersion-YYYY-MM-DD-HH-MM-SS-RandomString
-        prefix = f"{prefix}{'' if prefix.endswith('/') else '/'}"
+        prefix = f"{prefix}{'' if prefix.endswith('/') or prefix == '' else '/'}"
         now = utcnow()
         return (
             f"{prefix}{now.strftime('%Y/%m/%d/%H')}/"
@@ -456,9 +462,9 @@ class FirehoseBackend(BaseBackend):
         self,
         delivery_stream_name: str,
         version_id: str,
-        s3_destination: Dict[str, Any],
-        records: List[Dict[str, bytes]],
-    ) -> List[Dict[str, str]]:
+        s3_destination: dict[str, Any],
+        records: list[dict[str, bytes]],
+    ) -> list[dict[str, str]]:
         """Put records to a ExtendedS3 or S3 destination."""
         # Taken from LocalStack's firehose logic, with minor changes.
         bucket_name = s3_destination["BucketARN"].split(":")[-1]
@@ -469,7 +475,7 @@ class FirehoseBackend(BaseBackend):
 
         batched_data = b"".join([b64decode(r["Data"]) for r in records])
         try:
-            s3_backends[self.account_id]["global"].put_object(
+            s3_backends[self.account_id][self.partition].put_object(
                 bucket_name, object_path, batched_data
             )
         except Exception as exc:
@@ -480,8 +486,8 @@ class FirehoseBackend(BaseBackend):
         return [{"RecordId": str(mock_random.uuid4())} for _ in range(len(records))]
 
     def put_record_batch(
-        self, delivery_stream_name: str, records: List[Dict[str, bytes]]
-    ) -> Dict[str, Any]:
+        self, delivery_stream_name: str, records: list[dict[str, bytes]]
+    ) -> dict[str, Any]:
         """Write multiple data records into a Kinesis Data firehose stream."""
         delivery_stream = self.delivery_streams.get(delivery_stream_name)
         if not delivery_stream:
@@ -514,8 +520,8 @@ class FirehoseBackend(BaseBackend):
                 request_responses = self.put_http_records(
                     destination["HttpEndpoint"], records
                 )
-            elif "Elasticsearch" in destination or "Redshift" in destination:
-                # This isn't implmented as these services aren't implemented,
+            elif {"Elasticsearch", "Redshift", "Snowflake"} & set(destination):
+                # This isn't implemented as these services aren't implemented,
                 # so ignore the data, but return a "proper" response.
                 request_responses = [
                     {"RecordId": str(mock_random.uuid4())} for _ in range(len(records))
@@ -528,7 +534,7 @@ class FirehoseBackend(BaseBackend):
         }
 
     def tag_delivery_stream(
-        self, delivery_stream_name: str, tags: List[Dict[str, str]]
+        self, delivery_stream_name: str, tags: list[dict[str, str]]
     ) -> None:
         """Add/update tags for specified delivery stream."""
         delivery_stream = self.delivery_streams.get(delivery_stream_name)
@@ -552,7 +558,7 @@ class FirehoseBackend(BaseBackend):
         self.tagger.tag_resource(delivery_stream.delivery_stream_arn, tags)
 
     def untag_delivery_stream(
-        self, delivery_stream_name: str, tag_keys: List[str]
+        self, delivery_stream_name: str, tag_keys: list[str]
     ) -> None:
         """Removes tags from specified delivery stream."""
         delivery_stream = self.delivery_streams.get(delivery_stream_name)
@@ -567,7 +573,7 @@ class FirehoseBackend(BaseBackend):
         )
 
     def start_delivery_stream_encryption(
-        self, stream_name: str, encryption_config: Dict[str, Any]
+        self, stream_name: str, encryption_config: dict[str, Any]
     ) -> None:
         delivery_stream = self.delivery_streams.get(stream_name)
         if not delivery_stream:
@@ -587,18 +593,19 @@ class FirehoseBackend(BaseBackend):
 
         delivery_stream.delivery_stream_encryption_configuration["Status"] = "DISABLED"
 
-    def update_destination(  # pylint: disable=unused-argument
+    def update_destination(
         self,
         delivery_stream_name: str,
         current_delivery_stream_version_id: str,
         destination_id: str,
-        s3_destination_update: Dict[str, Any],
-        extended_s3_destination_update: Dict[str, Any],
+        s3_destination_update: dict[str, Any],
+        extended_s3_destination_update: dict[str, Any],
         s3_backup_mode: str,
-        redshift_destination_update: Dict[str, Any],
-        elasticsearch_destination_update: Dict[str, Any],
-        splunk_destination_update: Dict[str, Any],
-        http_endpoint_destination_update: Dict[str, Any],
+        redshift_destination_update: dict[str, Any],
+        elasticsearch_destination_update: dict[str, Any],
+        splunk_destination_update: dict[str, Any],
+        http_endpoint_destination_update: dict[str, Any],
+        snowflake_destination_configuration: dict[str, Any],
     ) -> None:
         (dest_name, dest_config) = find_destination_config_in_args(locals())
 
@@ -609,7 +616,10 @@ class FirehoseBackend(BaseBackend):
             )
 
         if dest_name == "Splunk":
-            warnings.warn("A Splunk destination delivery stream is not yet implemented")
+            warnings.warn(
+                "A Splunk destination delivery stream is not yet implemented",
+                stacklevel=2,
+            )
 
         if delivery_stream.version_id != current_delivery_stream_version_id:
             raise ConcurrentModificationException(
@@ -692,7 +702,7 @@ class FirehoseBackend(BaseBackend):
         filter_name: str,
         log_group_name: str,
         log_stream_name: str,
-        log_events: List[Dict[str, Any]],
+        log_events: list[dict[str, Any]],
     ) -> None:
         """Send log events to a S3 bucket after encoding and gzipping it."""
         data = {
