@@ -1,10 +1,10 @@
 import json
 import os
-import typing
 from collections import defaultdict
+from collections.abc import Iterable
 from copy import copy
 from datetime import datetime, timedelta
-from typing import Any, Dict, Iterable, List, Optional, Set, Tuple, Union
+from typing import Any, Optional, Union
 
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.common_models import BaseModel, CloudFormationModel
@@ -39,8 +39,8 @@ class Grant(BaseModel):
         key_id: str,
         name: str,
         grantee_principal: str,
-        operations: List[str],
-        constraints: Dict[str, Any],
+        operations: list[str],
+        constraints: dict[str, Any],
         retiring_principal: str,
     ):
         self.key_id = key_id
@@ -52,7 +52,7 @@ class Grant(BaseModel):
         self.id = mock_random.get_random_hex()
         self.token = mock_random.get_random_hex()
 
-    def to_json(self) -> Dict[str, Any]:
+    def to_json(self) -> dict[str, Any]:
         return {
             "KeyId": self.key_id,
             "GrantId": self.id,
@@ -87,7 +87,7 @@ class Key(CloudFormationModel):
         self.enabled = True
         self.multi_region = multi_region
         if self.multi_region:
-            self.multi_region_configuration: typing.Dict[str, Any] = {
+            self.multi_region_configuration: dict[str, Any] = {
                 "MultiRegionKeyType": "PRIMARY",
                 "PrimaryKey": {
                     "Arn": f"arn:{get_partition(region)}:kms:{region}:{account_id}:key/{self.id}",
@@ -105,16 +105,16 @@ class Key(CloudFormationModel):
         self.arn = (
             f"arn:{get_partition(region)}:kms:{region}:{account_id}:key/{self.id}"
         )
-        self.grants: Dict[str, Grant] = dict()
+        self.grants: dict[str, Grant] = {}
 
-        self.rotations: List[Dict[str, Any]] = []
+        self.rotations: list[dict[str, Any]] = []
 
     def add_grant(
         self,
         name: str,
         grantee_principal: str,
-        operations: List[str],
-        constraints: Dict[str, Any],
+        operations: list[str],
+        constraints: dict[str, Any],
         retiring_principal: str,
     ) -> Grant:
         grant = Grant(
@@ -128,11 +128,11 @@ class Key(CloudFormationModel):
         self.grants[grant.id] = grant
         return grant
 
-    def list_grants(self, grant_id: str) -> List[Grant]:
+    def list_grants(self, grant_id: str) -> list[Grant]:
         grant_ids = [grant_id] if grant_id else self.grants.keys()
         return [grant for _id, grant in self.grants.items() if _id in grant_ids]
 
-    def list_retirable_grants(self, retiring_principal: str) -> List[Grant]:
+    def list_retirable_grants(self, retiring_principal: str) -> list[Grant]:
         return [
             grant
             for grant in self.grants.values()
@@ -177,7 +177,7 @@ class Key(CloudFormationModel):
         return self.id
 
     @property
-    def encryption_algorithms(self) -> Optional[List[str]]:
+    def encryption_algorithms(self) -> Optional[list[str]]:
         if self.key_usage == "SIGN_VERIFY":
             return None
         elif self.key_spec == "SYMMETRIC_DEFAULT":
@@ -186,7 +186,7 @@ class Key(CloudFormationModel):
             return ["RSAES_OAEP_SHA_1", "RSAES_OAEP_SHA_256"]
 
     @property
-    def signing_algorithms(self) -> List[str]:
+    def signing_algorithms(self) -> list[str]:
         if self.key_usage == "ENCRYPT_DECRYPT":
             return None  # type: ignore[return-value]
         elif self.key_spec in KeySpec.ecc_key_specs():
@@ -204,7 +204,7 @@ class Key(CloudFormationModel):
         else:
             return []
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         key_dict = {
             "KeyMetadata": {
                 "AWSAccountId": self.account_id,
@@ -292,8 +292,8 @@ class KmsBackend(BaseBackend):
 
     def __init__(self, region_name: str, account_id: Optional[str] = None):
         super().__init__(region_name=region_name, account_id=account_id)  # type: ignore
-        self.keys: Dict[str, Key] = {}
-        self.key_to_aliases: Dict[str, Set[str]] = defaultdict(set)
+        self.keys: dict[str, Key] = {}
+        self.key_to_aliases: dict[str, set[str]] = defaultdict(set)
         self.tagger = TaggingService(key_name="TagKey", value_name="TagValue")
 
     def _generate_default_keys(self, alias_name: str) -> Optional[str]:
@@ -316,7 +316,7 @@ class KmsBackend(BaseBackend):
         key_usage: str,
         key_spec: str,
         description: str,
-        tags: Optional[List[Dict[str, str]]],
+        tags: Optional[list[dict[str, str]]],
         multi_region: bool = False,
         origin: str = "AWS_KMS",
     ) -> Key:
@@ -454,7 +454,7 @@ class KmsBackend(BaseBackend):
             if alias_name in aliases:
                 aliases.remove(alias_name)
 
-    def list_aliases(self) -> Dict[str, Set[str]]:
+    def list_aliases(self) -> dict[str, set[str]]:
         return self.key_to_aliases
 
     def get_key_id_from_alias(self, alias_name: str) -> Optional[str]:
@@ -507,8 +507,8 @@ class KmsBackend(BaseBackend):
             return unix_time(self.keys[key_id].deletion_date)
 
     def encrypt(
-        self, key_id: str, plaintext: bytes, encryption_context: Dict[str, str]
-    ) -> Tuple[bytes, str]:
+        self, key_id: str, plaintext: bytes, encryption_context: dict[str, str]
+    ) -> tuple[bytes, str]:
         key_id = self.any_id_to_key_id(key_id)
 
         ciphertext_blob = encrypt(
@@ -521,8 +521,8 @@ class KmsBackend(BaseBackend):
         return ciphertext_blob, arn
 
     def decrypt(
-        self, ciphertext_blob: bytes, encryption_context: Dict[str, str]
-    ) -> Tuple[bytes, str]:
+        self, ciphertext_blob: bytes, encryption_context: dict[str, str]
+    ) -> tuple[bytes, str]:
         plaintext, key_id = decrypt(
             master_keys=self.keys,
             ciphertext_blob=ciphertext_blob,
@@ -534,10 +534,10 @@ class KmsBackend(BaseBackend):
     def re_encrypt(
         self,
         ciphertext_blob: bytes,
-        source_encryption_context: Dict[str, str],
+        source_encryption_context: dict[str, str],
         destination_key_id: str,
-        destination_encryption_context: Dict[str, str],
-    ) -> Tuple[bytes, str, str]:
+        destination_encryption_context: dict[str, str],
+    ) -> tuple[bytes, str, str]:
         destination_key_id = self.any_id_to_key_id(destination_key_id)
 
         plaintext, decrypting_arn = self.decrypt(
@@ -559,10 +559,10 @@ class KmsBackend(BaseBackend):
     def generate_data_key(
         self,
         key_id: str,
-        encryption_context: Dict[str, str],
+        encryption_context: dict[str, str],
         number_of_bytes: int,
         key_spec: str,
-    ) -> Tuple[bytes, bytes, str]:
+    ) -> tuple[bytes, bytes, str]:
         key_id = self.any_id_to_key_id(key_id)
 
         if key_spec:
@@ -587,7 +587,7 @@ class KmsBackend(BaseBackend):
         # Responses uses 'generate_data_key'
         pass
 
-    def list_resource_tags(self, key_id_or_arn: str) -> Dict[str, List[Dict[str, str]]]:
+    def list_resource_tags(self, key_id_or_arn: str) -> dict[str, list[dict[str, str]]]:
         key_id = self.get_key_id(key_id_or_arn)
         if key_id in self.keys:
             return self.tagger.list_tags_for_resource(key_id)
@@ -596,7 +596,7 @@ class KmsBackend(BaseBackend):
             "The request was rejected because the specified entity or resource could not be found.",
         )
 
-    def tag_resource(self, key_id_or_arn: str, tags: List[Dict[str, str]]) -> None:
+    def tag_resource(self, key_id_or_arn: str, tags: list[dict[str, str]]) -> None:
         key_id = self.get_key_id(key_id_or_arn)
         if key_id in self.keys:
             self.tagger.tag_resource(key_id, tags)
@@ -606,7 +606,7 @@ class KmsBackend(BaseBackend):
             "The request was rejected because the specified entity or resource could not be found.",
         )
 
-    def untag_resource(self, key_id_or_arn: str, tag_names: List[str]) -> None:
+    def untag_resource(self, key_id_or_arn: str, tag_names: list[str]) -> None:
         key_id = self.get_key_id(key_id_or_arn)
         if key_id in self.keys:
             self.tagger.untag_resource_using_names(key_id, tag_names)
@@ -620,11 +620,11 @@ class KmsBackend(BaseBackend):
         self,
         key_id: str,
         grantee_principal: str,
-        operations: List[str],
+        operations: list[str],
         name: str,
-        constraints: Dict[str, Any],
+        constraints: dict[str, Any],
         retiring_principal: str,
-    ) -> Tuple[str, str]:
+    ) -> tuple[str, str]:
         key = self.describe_key(key_id)
         grant = key.add_grant(
             name,
@@ -635,11 +635,11 @@ class KmsBackend(BaseBackend):
         )
         return grant.id, grant.token
 
-    def list_grants(self, key_id: str, grant_id: str) -> List[Grant]:
+    def list_grants(self, key_id: str, grant_id: str) -> list[Grant]:
         key = self.describe_key(key_id)
         return key.list_grants(grant_id)
 
-    def list_retirable_grants(self, retiring_principal: str) -> List[Grant]:
+    def list_retirable_grants(self, retiring_principal: str) -> list[Grant]:
         grants = []
         for key in self.keys.values():
             grants.extend(key.list_retirable_grants(retiring_principal))
@@ -660,10 +660,8 @@ class KmsBackend(BaseBackend):
     def __ensure_valid_sign_and_verify_key(self, key: Key) -> None:
         if key.key_usage != "SIGN_VERIFY":
             raise ValidationException(
-                (
-                    "1 validation error detected: Value '{key_id}' at 'KeyId' failed "
-                    "to satisfy constraint: Member must point to a key with usage: 'SIGN_VERIFY'"
-                ).format(key_id=key.id)
+                f"1 validation error detected: Value '{key.id}' at 'KeyId' failed "
+                "to satisfy constraint: Member must point to a key with usage: 'SIGN_VERIFY'"
             )
 
     def __ensure_valid_signing_algorithm(
@@ -671,29 +669,22 @@ class KmsBackend(BaseBackend):
     ) -> None:
         if signing_algorithm not in key.signing_algorithms:
             raise ValidationException(
-                (
-                    "1 validation error detected: Value '{signing_algorithm}' at 'SigningAlgorithm' failed "
-                    "to satisfy constraint: Member must satisfy enum value set: "
-                    "{valid_sign_algorithms}"
-                ).format(
-                    signing_algorithm=signing_algorithm,
-                    valid_sign_algorithms=key.signing_algorithms,
-                )
+                f"1 validation error detected: Value '{signing_algorithm}' at 'SigningAlgorithm' failed "
+                "to satisfy constraint: Member must satisfy enum value set: "
+                f"{key.signing_algorithms}"
             )
 
     def __ensure_valid_key_spec(self, key_spec: str) -> None:
         if key_spec not in KeySpec.key_specs():
             raise ValidationException(
-                (
-                    "1 validation error detected: Value '{key_spec}' at 'KeySpec' failed "
-                    "to satisfy constraint: Member must satisfy enum value set: "
-                    "{valid_key_specs}"
-                ).format(key_spec=key_spec, valid_key_specs=KeySpec.key_specs())
+                f"1 validation error detected: Value '{key_spec}' at 'KeySpec' failed "
+                "to satisfy constraint: Member must satisfy enum value set: "
+                f"{KeySpec.key_specs()}"
             )
 
     def sign(
         self, key_id: str, message: bytes, signing_algorithm: str
-    ) -> Tuple[str, bytes, str]:
+    ) -> tuple[str, bytes, str]:
         """
         Sign message using generated private key.
 
@@ -710,7 +701,7 @@ class KmsBackend(BaseBackend):
 
     def verify(
         self, key_id: str, message: bytes, signature: bytes, signing_algorithm: str
-    ) -> Tuple[str, bool, str]:
+    ) -> tuple[str, bool, str]:
         """
         Verify message using public key from generated private key.
 
@@ -724,14 +715,9 @@ class KmsBackend(BaseBackend):
 
         if signing_algorithm not in key.signing_algorithms:
             raise ValidationException(
-                (
-                    "1 validation error detected: Value '{signing_algorithm}' at 'SigningAlgorithm' failed "
-                    "to satisfy constraint: Member must satisfy enum value set: "
-                    "{valid_sign_algorithms}"
-                ).format(
-                    signing_algorithm=signing_algorithm,
-                    valid_sign_algorithms=key.signing_algorithms,
-                )
+                f"1 validation error detected: Value '{signing_algorithm}' at 'SigningAlgorithm' failed "
+                "to satisfy constraint: Member must satisfy enum value set: "
+                f"{key.signing_algorithms}"
             )
 
         return (
@@ -740,7 +726,7 @@ class KmsBackend(BaseBackend):
             signing_algorithm,
         )
 
-    def get_public_key(self, key_id: str) -> Tuple[Key, bytes]:
+    def get_public_key(self, key_id: str) -> tuple[Key, bytes]:
         key = self.describe_key(key_id)
         return key, key.private_key.public_key()
 
@@ -761,7 +747,7 @@ class KmsBackend(BaseBackend):
     @paginate(PAGINATION_MODEL)
     def list_key_rotations(
         self, key_id: str, limit: int, next_marker: str
-    ) -> List[Dict[str, Union[str, float]]]:
+    ) -> list[dict[str, Union[str, float]]]:
         key: Key = self.keys[self.get_key_id(key_id)]
 
         return key.rotations
@@ -771,9 +757,9 @@ class KmsBackend(BaseBackend):
         message: bytes,
         key_id: str,
         mac_algorithm: str,
-        grant_tokens: List[str],
+        grant_tokens: list[str],
         dry_run: bool,
-    ) -> Tuple[str, str, str]:
+    ) -> tuple[str, str, str]:
         key = self.keys[key_id]
 
         if (
@@ -793,7 +779,7 @@ class KmsBackend(BaseBackend):
         key_id: str,
         mac_algorithm: str,
         mac: str,
-        grant_tokens: List[str],
+        grant_tokens: list[str],
         dry_run: bool,
     ) -> None:
         regenerated_mac, _, _ = self.generate_mac(
