@@ -684,8 +684,10 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
                     tags = format_tags(self.ec2_backend.tags.get(resource.id, {}))
                     if not tags or not tag_filter(tags):
                         continue
+                    resource_type_part = resource_type.split(":", 1)[1]
+                    resource_arn = f"arn:{self.partition}:ec2:{self.region_name}:{self.account_id}:{resource_type_part}/{resource.id}"
                     yield {
-                        "ResourceARN": f"arn:{self.partition}:ec2:{self.region_name}:{self.account_id}:{resource_type}/{resource.id}",
+                        "ResourceARN": resource_arn,
                         "Tags": tags,
                     }
 
@@ -1016,7 +1018,11 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
                     yield {"ResourceARN": f"{secret.arn}", "Tags": formated_tags}
 
         # SQS
-        if not resource_type_filters or "sqs" in resource_type_filters:
+        if (
+            not resource_type_filters
+            or "sqs" in resource_type_filters
+            or "sqs:queue" in resource_type_filters
+        ):
             for queue in self.sqs_backend.queues.values():
                 tags = format_tags(queue.tags)
                 if not tags or not tag_filter(
