@@ -1,6 +1,6 @@
 from collections import defaultdict
 from datetime import datetime
-from typing import Any, Dict, List, Optional
+from typing import Any, Optional
 
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.common_models import BaseModel
@@ -10,7 +10,7 @@ from moto.s3.exceptions import (
     NoSuchPublicAccessBlockConfiguration,
     WrongPublicAccessBlockAccountIdError,
 )
-from moto.s3.models import PublicAccessBlock
+from moto.s3.models import PublicAccessBlock, S3Backend, s3_backends
 from moto.utilities.paginator import paginate
 from moto.utilities.tagging_service import TaggingService
 from moto.utilities.utils import PARTITION_NAMES, get_partition
@@ -23,6 +23,12 @@ PAGINATION_MODEL = {
         "limit_default": 100,
         "unique_attribute": "id",
     },
+    "list_access_points": {
+        "input_token": "next_token",
+        "limit_key": "max_results",
+        "limit_default": 1000,
+        "unique_attribute": "name",
+    },
 }
 
 
@@ -33,8 +39,8 @@ class AccessPoint(BaseModel):
         region_name: str,
         name: str,
         bucket: str,
-        vpc_configuration: Dict[str, Any],
-        public_access_block_configuration: Dict[str, Any],
+        vpc_configuration: dict[str, Any],
+        public_access_block_configuration: dict[str, Any],
     ):
         self.name = name
         self.alias = f"{name}-{mock_random.get_random_hex(34)}-s3alias"
@@ -67,8 +73,8 @@ class StorageLensConfiguration(BaseModel):
         self,
         account_id: str,
         config_id: str,
-        storage_lens_configuration: Dict[str, Any],
-        tags: Optional[Dict[str, str]] = None,
+        storage_lens_configuration: dict[str, Any],
+        tags: Optional[dict[str, str]] = None,
     ):
         self.account_id = account_id
         self.config_id = config_id
@@ -81,8 +87,8 @@ class S3ControlBackend(BaseBackend):
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
         self.public_access_block: Optional[PublicAccessBlock] = None
-        self.access_points: Dict[str, Dict[str, AccessPoint]] = defaultdict(dict)
-        self.storage_lens_configs: Dict[str, StorageLensConfiguration] = {}
+        self.access_points: dict[str, dict[str, AccessPoint]] = defaultdict(dict)
+        self.storage_lens_configs: dict[str, StorageLensConfiguration] = {}
         self.tagger = TaggingService()
 
     def get_public_access_block(self, account_id: str) -> PublicAccessBlock:
@@ -103,7 +109,7 @@ class S3ControlBackend(BaseBackend):
         self.public_access_block = None
 
     def put_public_access_block(
-        self, account_id: str, pub_block_config: Dict[str, Any]
+        self, account_id: str, pub_block_config: dict[str, Any]
     ) -> None:
         # The account ID should equal the account id that is set for Moto:
         if account_id != self.account_id:
@@ -124,8 +130,8 @@ class S3ControlBackend(BaseBackend):
         account_id: str,
         name: str,
         bucket: str,
-        vpc_configuration: Dict[str, Any],
-        public_access_block_configuration: Dict[str, Any],
+        vpc_configuration: dict[str, Any],
+        public_access_block_configuration: dict[str, Any],
     ) -> AccessPoint:
         access_point = AccessPoint(
             account_id,
@@ -171,8 +177,8 @@ class S3ControlBackend(BaseBackend):
         self,
         config_id: str,
         account_id: str,
-        storage_lens_configuration: Dict[str, Any],
-        tags: Optional[Dict[str, str]] = None,
+        storage_lens_configuration: dict[str, Any],
+        tags: Optional[dict[str, str]] = None,
     ) -> None:
         # The account ID should equal the account id that is set for Moto:
         if account_id != self.account_id:
@@ -198,12 +204,27 @@ class S3ControlBackend(BaseBackend):
     @paginate(pagination_model=PAGINATION_MODEL)
     def list_storage_lens_configurations(
         self, account_id: str
-    ) -> List[StorageLensConfiguration]:
+    ) -> list[StorageLensConfiguration]:
         storage_lens_configuration_list = list(self.storage_lens_configs.values())
         return storage_lens_configuration_list
 
+    @paginate(pagination_model=PAGINATION_MODEL)
+    def list_access_points(
+        self,
+        account_id: str,
+        bucket: Optional[str] = None,
+        max_results: Optional[int] = None,
+        next_token: Optional[str] = None,
+    ) -> list[AccessPoint]:
+        account_access_points = self.access_points.get(account_id, {})
+        all_access_points = list(account_access_points.values())
+
+        if bucket:
+            return [ap for ap in all_access_points if ap.bucket == bucket]
+        return all_access_points
+
     def put_storage_lens_configuration_tagging(
-        self, config_id: str, account_id: str, tags: Dict[str, str]
+        self, config_id: str, account_id: str, tags: dict[str, str]
     ) -> None:
         # The account ID should equal the account id that is set for Moto:
         if account_id != self.account_id:
@@ -216,7 +237,7 @@ class S3ControlBackend(BaseBackend):
 
     def get_storage_lens_configuration_tagging(
         self, config_id: str, account_id: str
-    ) -> Dict[str, str]:
+    ) -> dict[str, str]:
         if account_id != self.account_id:
             raise WrongPublicAccessBlockAccountIdError()
         if config_id not in self.storage_lens_configs:
@@ -224,6 +245,18 @@ class S3ControlBackend(BaseBackend):
 
         return self.storage_lens_configs[config_id].tags
 
+    def list_tags_for_resource(self, resource_arn: str) -> list[dict[str, str]]:
+        backend: S3Backend = s3_backends[self.account_id][self.partition]
+        return backend.tagger.list_tags_for_resource(resource_arn)["Tags"]
+
+    def tag_resource(self, resource_arn: str, tags: list[dict[str, str]]) -> None:
+        backend: S3Backend = s3_backends[self.account_id][self.partition]
+        backend.tagger.tag_resource(resource_arn, tags=tags)
+
+    def untag_resource(self, resource_arn: str, tag_keys: list[str]) -> None:
+        backend: S3Backend = s3_backends[self.account_id][self.partition]
+        backend.tagger.untag_resource_using_names(resource_arn, tag_names=tag_keys)
+
 
 s3control_backends = BackendDict(
     S3ControlBackend,
