@@ -11,8 +11,7 @@ class _InvalidOperationException(SecurityHubClientError):
     def __init__(self, error_type: str, op: str, msg: str):
         super().__init__(
             error_type,
-            "An error occurred (%s) when calling the %s operation: %s"
-            % (error_type, op, msg),
+            f"An error occurred ({error_type}) when calling the {op} operation: {msg}",
         )
 
 
