@@ -1,15 +1,19 @@
+from collections.abc import Iterable
 from datetime import datetime
-from typing import List, Optional, TypedDict
+from enum import Enum
+from typing import IO, Optional, TypedDict, Union
 
 from ..exceptions import AWSError as ServiceException
 
 AliasDescription = str
+Arn = str
 CharacterRestrictedName = str
 ClientToken = str
 ConnectorParameters = str
 Definition = str
 Enabled = bool
 ErrorMessage = str
+EvaluationFailureLocation = str
 HTTPBody = str
 HTTPHeaders = str
 HTTPMethod = str
@@ -19,7 +23,10 @@ HTTPStatusMessage = str
 Identity = str
 IncludeExecutionData = bool
 IncludeExecutionDataGetExecutionHistory = bool
+KmsDataKeyReusePeriodSeconds = int
+KmsKeyId = str
 ListExecutionsPageToken = str
+LongArn = str
 MapRunLabel = str
 MaxConcurrency = int
 Name = str
@@ -42,24 +49,36 @@ ToleratedFailurePercentage = float
 TraceHeader = str
 URL = str
 UnsignedInteger = int
+ValidateStateMachineDefinitionCode = str
+ValidateStateMachineDefinitionLocation = str
+ValidateStateMachineDefinitionMaxResult = int
+ValidateStateMachineDefinitionMessage = str
+ValidateStateMachineDefinitionTruncated = bool
+VariableName = str
+VariableValue = str
 VersionDescription = str
 VersionWeight = int
 includedDetails = bool
 truncated = bool
 
 
-class ExecutionRedriveFilter(str):
+class EncryptionType(str, Enum):
+    AWS_OWNED_KEY = "AWS_OWNED_KEY"
+    CUSTOMER_MANAGED_KMS_KEY = "CUSTOMER_MANAGED_KMS_KEY"
+
+
+class ExecutionRedriveFilter(str, Enum):
     REDRIVEN = "REDRIVEN"
     NOT_REDRIVEN = "NOT_REDRIVEN"
 
 
-class ExecutionRedriveStatus(str):
+class ExecutionRedriveStatus(str, Enum):
     REDRIVABLE = "REDRIVABLE"
     NOT_REDRIVABLE = "NOT_REDRIVABLE"
     REDRIVABLE_BY_MAP_RUN = "REDRIVABLE_BY_MAP_RUN"
 
 
-class ExecutionStatus(str):
+class ExecutionStatus(str, Enum):
     RUNNING = "RUNNING"
     SUCCEEDED = "SUCCEEDED"
     FAILED = "FAILED"
@@ -68,7 +87,7 @@ class ExecutionStatus(str):
     PENDING_REDRIVE = "PENDING_REDRIVE"
 
 
-class HistoryEventType(str):
+class HistoryEventType(str, Enum):
     ActivityFailed = "ActivityFailed"
     ActivityScheduled = "ActivityScheduled"
     ActivityScheduleFailed = "ActivityScheduleFailed"
@@ -130,58 +149,88 @@ class HistoryEventType(str):
     MapRunSucceeded = "MapRunSucceeded"
     ExecutionRedriven = "ExecutionRedriven"
     MapRunRedriven = "MapRunRedriven"
+    EvaluationFailed = "EvaluationFailed"
 
 
-class InspectionLevel(str):
+class IncludedData(str, Enum):
+    ALL_DATA = "ALL_DATA"
+    METADATA_ONLY = "METADATA_ONLY"
+
+
+class InspectionLevel(str, Enum):
     INFO = "INFO"
     DEBUG = "DEBUG"
     TRACE = "TRACE"
 
 
-class LogLevel(str):
+class KmsKeyState(str, Enum):
+    DISABLED = "DISABLED"
+    PENDING_DELETION = "PENDING_DELETION"
+    PENDING_IMPORT = "PENDING_IMPORT"
+    UNAVAILABLE = "UNAVAILABLE"
+    CREATING = "CREATING"
+
+
+class LogLevel(str, Enum):
     ALL = "ALL"
     ERROR = "ERROR"
     FATAL = "FATAL"
     OFF = "OFF"
 
 
-class MapRunStatus(str):
+class MapRunStatus(str, Enum):
     RUNNING = "RUNNING"
     SUCCEEDED = "SUCCEEDED"
     FAILED = "FAILED"
     ABORTED = "ABORTED"
 
 
-class StateMachineStatus(str):
+class StateMachineStatus(str, Enum):
     ACTIVE = "ACTIVE"
     DELETING = "DELETING"
 
 
-class StateMachineType(str):
+class StateMachineType(str, Enum):
     STANDARD = "STANDARD"
     EXPRESS = "EXPRESS"
 
 
-class SyncExecutionStatus(str):
+class SyncExecutionStatus(str, Enum):
     SUCCEEDED = "SUCCEEDED"
     FAILED = "FAILED"
     TIMED_OUT = "TIMED_OUT"
 
 
-class TestExecutionStatus(str):
+class TestExecutionStatus(str, Enum):
     SUCCEEDED = "SUCCEEDED"
     FAILED = "FAILED"
     RETRIABLE = "RETRIABLE"
     CAUGHT_ERROR = "CAUGHT_ERROR"
 
 
-class ValidationExceptionReason(str):
+class ValidateStateMachineDefinitionResultCode(str, Enum):
+    OK = "OK"
+    FAIL = "FAIL"
+
+
+class ValidateStateMachineDefinitionSeverity(str, Enum):
+    ERROR = "ERROR"
+    WARNING = "WARNING"
+
+
+class ValidationExceptionReason(str, Enum):
     API_DOES_NOT_SUPPORT_LABELED_ARNS = "API_DOES_NOT_SUPPORT_LABELED_ARNS"
     MISSING_REQUIRED_PARAMETER = "MISSING_REQUIRED_PARAMETER"
     CANNOT_UPDATE_COMPLETED_MAP_RUN = "CANNOT_UPDATE_COMPLETED_MAP_RUN"
     INVALID_ROUTING_CONFIGURATION = "INVALID_ROUTING_CONFIGURATION"
 
 
+class ActivityAlreadyExists(ServiceException):
+    code: str = "ActivityAlreadyExists"
+    sender_fault: bool = False
+    status_code: int = 400
+
+
 class ActivityDoesNotExist(ServiceException):
     code: str = "ActivityDoesNotExist"
     sender_fault: bool = False
@@ -242,6 +291,12 @@ class InvalidDefinition(ServiceException):
     status_code: int = 400
 
 
+class InvalidEncryptionConfiguration(ServiceException):
+    code: str = "InvalidEncryptionConfiguration"
+    sender_fault: bool = False
+    status_code: int = 400
+
+
 class InvalidExecutionInput(ServiceException):
     code: str = "InvalidExecutionInput"
     sender_fault: bool = False
@@ -283,6 +338,25 @@ class InvalidTracingConfiguration(ServiceException):
     status_code: int = 400
 
 
+class KmsAccessDeniedException(ServiceException):
+    code: str = "KmsAccessDeniedException"
+    sender_fault: bool = False
+    status_code: int = 400
+
+
+class KmsInvalidStateException(ServiceException):
+    code: str = "KmsInvalidStateException"
+    sender_fault: bool = False
+    status_code: int = 400
+    kmsKeyState: Optional[KmsKeyState]
+
+
+class KmsThrottlingException(ServiceException):
+    code: str = "KmsThrottlingException"
+    sender_fault: bool = False
+    status_code: int = 400
+
+
 class MissingRequiredParameter(ServiceException):
     code: str = "MissingRequiredParameter"
     sender_fault: bool = False
@@ -293,7 +367,7 @@ class ResourceNotFound(ServiceException):
     code: str = "ResourceNotFound"
     sender_fault: bool = False
     status_code: int = 400
-    resourceName: Optional[str]
+    resourceName: Optional[Arn]
 
 
 class ServiceQuotaExceededException(ServiceException):
@@ -344,6 +418,13 @@ class TaskTimedOut(ServiceException):
     status_code: int = 400
 
 
+class TooManyTags(ServiceException):
+    code: str = "TooManyTags"
+    sender_fault: bool = False
+    status_code: int = 400
+    resourceName: Optional[Arn]
+
+
 class ValidationException(ServiceException):
     code: str = "ValidationException"
     sender_fault: bool = False
@@ -360,12 +441,12 @@ Timestamp = datetime
 
 
 class ActivityListItem(TypedDict, total=False):
-    activityArn: str
+    activityArn: Arn
     name: Name
     creationDate: Timestamp
 
 
-ActivityList = List[ActivityListItem]
+ActivityList = list[ActivityListItem]
 
 
 class ActivityScheduleFailedEventDetails(TypedDict, total=False):
@@ -381,7 +462,7 @@ class HistoryEventExecutionDataDetails(TypedDict, total=False):
 
 
 class ActivityScheduledEventDetails(TypedDict, total=False):
-    resource: str
+    resource: Arn
     input: Optional[SensitiveData]
     inputDetails: Optional[HistoryEventExecutionDataDetails]
     timeoutInSeconds: Optional[TimeoutInSeconds]
@@ -402,6 +483,13 @@ class ActivityTimedOutEventDetails(TypedDict, total=False):
     cause: Optional[SensitiveCause]
 
 
+AssignedVariables = dict[VariableName, VariableValue]
+
+
+class AssignedVariablesDetails(TypedDict, total=False):
+    truncated: Optional[truncated]
+
+
 BilledDuration = int
 BilledMemoryUsed = int
 
@@ -416,7 +504,13 @@ class CloudWatchEventsExecutionDataDetails(TypedDict, total=False):
 
 
 class CloudWatchLogsLogGroup(TypedDict, total=False):
-    logGroupArn: Optional[str]
+    logGroupArn: Optional[Arn]
+
+
+class EncryptionConfiguration(TypedDict, total=False):
+    kmsKeyId: Optional[KmsKeyId]
+    kmsDataKeyReusePeriodSeconds: Optional[KmsDataKeyReusePeriodSeconds]
+    type: EncryptionType
 
 
 class Tag(TypedDict, total=False):
@@ -424,33 +518,27 @@ class Tag(TypedDict, total=False):
     value: Optional[TagValue]
 
 
-TagList = List[Tag]
+TagList = list[Tag]
 
 
 class CreateActivityOutput(TypedDict, total=False):
-    activityArn: str
+    activityArn: Arn
     creationDate: Timestamp
 
 
 class RoutingConfigurationListItem(TypedDict, total=False):
-    stateMachineVersionArn: str
+    stateMachineVersionArn: Arn
     weight: VersionWeight
 
 
-RoutingConfigurationList = List[RoutingConfigurationListItem]
+RoutingConfigurationList = list[RoutingConfigurationListItem]
 
 
 class CreateStateMachineAliasOutput(TypedDict, total=False):
-    stateMachineAliasArn: str
+    stateMachineAliasArn: Arn
     creationDate: Timestamp
 
 
-class EncryptionConfiguration(TypedDict, total=False):
-    type: str
-    kmsDataKeyReusePeriodSeconds: Optional[int]
-    kmsKeyId: Optional[str]
-
-
 class TracingConfiguration(TypedDict, total=False):
     enabled: Optional[Enabled]
 
@@ -459,7 +547,7 @@ class LogDestination(TypedDict, total=False):
     cloudWatchLogsLogGroup: Optional[CloudWatchLogsLogGroup]
 
 
-LogDestinationList = List[LogDestination]
+LogDestinationList = list[LogDestination]
 
 
 class LoggingConfiguration(TypedDict, total=False):
@@ -468,28 +556,23 @@ class LoggingConfiguration(TypedDict, total=False):
     destinations: Optional[LogDestinationList]
 
 
-CreateStateMachineInput = TypedDict(
-    "CreateStateMachineInput",
-    {
-        "name": Name,
-        "definition": Definition,
-        "roleArn": str,
-        "type": Optional[StateMachineType],
-        "loggingConfiguration": Optional[LoggingConfiguration],
-        "tags": Optional[TagList],
-        "tracingConfiguration": Optional[TracingConfiguration],
-        "encryptionConfiguration": Optional[EncryptionConfiguration],
-        "publish": Optional[Publish],
-        "versionDescription": Optional[VersionDescription],
-    },
-    total=False,
-)
+class CreateStateMachineInput(TypedDict, total=False):
+    name: Name
+    definition: Definition
+    roleArn: Arn
+    type: Optional[StateMachineType]
+    loggingConfiguration: Optional[LoggingConfiguration]
+    tags: Optional[TagList]
+    tracingConfiguration: Optional[TracingConfiguration]
+    publish: Optional[Publish]
+    versionDescription: Optional[VersionDescription]
+    encryptionConfiguration: Optional[EncryptionConfiguration]
 
 
 class CreateStateMachineOutput(TypedDict, total=False):
-    stateMachineArn: str
+    stateMachineArn: Arn
     creationDate: Timestamp
-    stateMachineVersionArn: Optional[str]
+    stateMachineVersionArn: Optional[Arn]
 
 
 class DeleteActivityOutput(TypedDict, total=False):
@@ -509,14 +592,15 @@ class DeleteStateMachineVersionOutput(TypedDict, total=False):
 
 
 class DescribeActivityOutput(TypedDict, total=False):
-    activityArn: str
+    activityArn: Arn
     name: Name
     creationDate: Timestamp
+    encryptionConfiguration: Optional[EncryptionConfiguration]
 
 
 class DescribeExecutionOutput(TypedDict, total=False):
-    executionArn: str
-    stateMachineArn: str
+    executionArn: Arn
+    stateMachineArn: Arn
     name: Optional[Name]
     status: ExecutionStatus
     startDate: Timestamp
@@ -526,11 +610,11 @@ class DescribeExecutionOutput(TypedDict, total=False):
     output: Optional[SensitiveData]
     outputDetails: Optional[CloudWatchEventsExecutionDataDetails]
     traceHeader: Optional[TraceHeader]
-    mapRunArn: Optional[str]
+    mapRunArn: Optional[LongArn]
     error: Optional[SensitiveError]
     cause: Optional[SensitiveCause]
-    stateMachineVersionArn: Optional[str]
-    stateMachineAliasArn: Optional[str]
+    stateMachineVersionArn: Optional[Arn]
+    stateMachineAliasArn: Optional[Arn]
     redriveCount: Optional[RedriveCount]
     redriveDate: Optional[Timestamp]
     redriveStatus: Optional[ExecutionRedriveStatus]
@@ -571,8 +655,8 @@ ToleratedFailureCount = int
 
 
 class DescribeMapRunOutput(TypedDict, total=False):
-    mapRunArn: str
-    executionArn: str
+    mapRunArn: LongArn
+    executionArn: Arn
     status: MapRunStatus
     startDate: Timestamp
     stopDate: Optional[Timestamp]
@@ -586,7 +670,7 @@ class DescribeMapRunOutput(TypedDict, total=False):
 
 
 class DescribeStateMachineAliasOutput(TypedDict, total=False):
-    stateMachineAliasArn: Optional[str]
+    stateMachineAliasArn: Optional[Arn]
     name: Optional[Name]
     description: Optional[AliasDescription]
     routingConfiguration: Optional[RoutingConfigurationList]
@@ -594,39 +678,49 @@ class DescribeStateMachineAliasOutput(TypedDict, total=False):
     updateDate: Optional[Timestamp]
 
 
+VariableNameList = list[VariableName]
+VariableReferences = dict[StateName, VariableNameList]
+
+
 class DescribeStateMachineForExecutionOutput(TypedDict, total=False):
-    stateMachineArn: str
+    stateMachineArn: Arn
     name: Name
     definition: Definition
-    roleArn: str
+    roleArn: Arn
     updateDate: Timestamp
     loggingConfiguration: Optional[LoggingConfiguration]
     tracingConfiguration: Optional[TracingConfiguration]
-    encryptionConfiguration: Optional[EncryptionConfiguration]
-    mapRunArn: Optional[str]
+    mapRunArn: Optional[LongArn]
     label: Optional[MapRunLabel]
     revisionId: Optional[RevisionId]
+    encryptionConfiguration: Optional[EncryptionConfiguration]
+    variableReferences: Optional[VariableReferences]
+
+
+class DescribeStateMachineOutput(TypedDict, total=False):
+    stateMachineArn: Arn
+    name: Name
+    status: Optional[StateMachineStatus]
+    definition: Definition
+    roleArn: Arn
+    type: StateMachineType
+    creationDate: Timestamp
+    loggingConfiguration: Optional[LoggingConfiguration]
+    tracingConfiguration: Optional[TracingConfiguration]
+    label: Optional[MapRunLabel]
+    revisionId: Optional[RevisionId]
+    description: Optional[VersionDescription]
+    encryptionConfiguration: Optional[EncryptionConfiguration]
+    variableReferences: Optional[VariableReferences]
+
+
+class EvaluationFailedEventDetails(TypedDict, total=False):
+    error: Optional[SensitiveError]
+    cause: Optional[SensitiveCause]
+    location: Optional[EvaluationFailureLocation]
+    state: StateName
 
 
-DescribeStateMachineOutput = TypedDict(
-    "DescribeStateMachineOutput",
-    {
-        "stateMachineArn": str,
-        "name": Name,
-        "status": Optional[StateMachineStatus],
-        "definition": Definition,
-        "roleArn": str,
-        "type": StateMachineType,
-        "creationDate": Timestamp,
-        "loggingConfiguration": Optional[LoggingConfiguration],
-        "tracingConfiguration": Optional[TracingConfiguration],
-        "encryptionConfiguration": Optional[EncryptionConfiguration],
-        "label": Optional[MapRunLabel],
-        "revisionId": Optional[RevisionId],
-        "description": Optional[VersionDescription],
-    },
-    total=False,
-)
 EventId = int
 
 
@@ -641,21 +735,21 @@ class ExecutionFailedEventDetails(TypedDict, total=False):
 
 
 class ExecutionListItem(TypedDict, total=False):
-    executionArn: str
-    stateMachineArn: str
+    executionArn: Arn
+    stateMachineArn: Arn
     name: Name
     status: ExecutionStatus
     startDate: Timestamp
     stopDate: Optional[Timestamp]
-    mapRunArn: Optional[str]
+    mapRunArn: Optional[LongArn]
     itemCount: Optional[UnsignedInteger]
-    stateMachineVersionArn: Optional[str]
-    stateMachineAliasArn: Optional[str]
+    stateMachineVersionArn: Optional[Arn]
+    stateMachineAliasArn: Optional[Arn]
     redriveCount: Optional[RedriveCount]
     redriveDate: Optional[Timestamp]
 
 
-ExecutionList = List[ExecutionListItem]
+ExecutionList = list[ExecutionListItem]
 
 
 class ExecutionRedrivenEventDetails(TypedDict, total=False):
@@ -665,9 +759,9 @@ class ExecutionRedrivenEventDetails(TypedDict, total=False):
 class ExecutionStartedEventDetails(TypedDict, total=False):
     input: Optional[SensitiveData]
     inputDetails: Optional[HistoryEventExecutionDataDetails]
-    roleArn: Optional[str]
-    stateMachineAliasArn: Optional[str]
-    stateMachineVersionArn: Optional[str]
+    roleArn: Optional[Arn]
+    stateMachineAliasArn: Optional[Arn]
+    stateMachineVersionArn: Optional[Arn]
 
 
 class ExecutionSucceededEventDetails(TypedDict, total=False):
@@ -686,7 +780,7 @@ class GetActivityTaskOutput(TypedDict, total=False):
 
 
 class MapRunRedrivenEventDetails(TypedDict, total=False):
-    mapRunArn: Optional[str]
+    mapRunArn: Optional[LongArn]
     redriveCount: Optional[RedriveCount]
 
 
@@ -696,13 +790,15 @@ class MapRunFailedEventDetails(TypedDict, total=False):
 
 
 class MapRunStartedEventDetails(TypedDict, total=False):
-    mapRunArn: Optional[str]
+    mapRunArn: Optional[LongArn]
 
 
 class StateExitedEventDetails(TypedDict, total=False):
     name: Name
     output: Optional[SensitiveData]
     outputDetails: Optional[HistoryEventExecutionDataDetails]
+    assignedVariables: Optional[AssignedVariables]
+    assignedVariablesDetails: Optional[AssignedVariablesDetails]
 
 
 class StateEnteredEventDetails(TypedDict, total=False):
@@ -727,11 +823,11 @@ class LambdaFunctionStartFailedEventDetails(TypedDict, total=False):
 
 
 class TaskCredentials(TypedDict, total=False):
-    roleArn: Optional[str]
+    roleArn: Optional[LongArn]
 
 
 class LambdaFunctionScheduledEventDetails(TypedDict, total=False):
-    resource: str
+    resource: Arn
     input: Optional[SensitiveData]
     inputDetails: Optional[HistoryEventExecutionDataDetails]
     timeoutInSeconds: Optional[TimeoutInSeconds]
@@ -814,65 +910,55 @@ class TaskFailedEventDetails(TypedDict, total=False):
     cause: Optional[SensitiveCause]
 
 
-HistoryEvent = TypedDict(
-    "HistoryEvent",
-    {
-        "timestamp": Timestamp,
-        "type": HistoryEventType,
-        "id": EventId,
-        "previousEventId": Optional[EventId],
-        "activityFailedEventDetails": Optional[ActivityFailedEventDetails],
-        "activityScheduleFailedEventDetails": Optional[
-            ActivityScheduleFailedEventDetails
-        ],
-        "activityScheduledEventDetails": Optional[ActivityScheduledEventDetails],
-        "activityStartedEventDetails": Optional[ActivityStartedEventDetails],
-        "activitySucceededEventDetails": Optional[ActivitySucceededEventDetails],
-        "activityTimedOutEventDetails": Optional[ActivityTimedOutEventDetails],
-        "taskFailedEventDetails": Optional[TaskFailedEventDetails],
-        "taskScheduledEventDetails": Optional[TaskScheduledEventDetails],
-        "taskStartFailedEventDetails": Optional[TaskStartFailedEventDetails],
-        "taskStartedEventDetails": Optional[TaskStartedEventDetails],
-        "taskSubmitFailedEventDetails": Optional[TaskSubmitFailedEventDetails],
-        "taskSubmittedEventDetails": Optional[TaskSubmittedEventDetails],
-        "taskSucceededEventDetails": Optional[TaskSucceededEventDetails],
-        "taskTimedOutEventDetails": Optional[TaskTimedOutEventDetails],
-        "executionFailedEventDetails": Optional[ExecutionFailedEventDetails],
-        "executionStartedEventDetails": Optional[ExecutionStartedEventDetails],
-        "executionSucceededEventDetails": Optional[ExecutionSucceededEventDetails],
-        "executionAbortedEventDetails": Optional[ExecutionAbortedEventDetails],
-        "executionTimedOutEventDetails": Optional[ExecutionTimedOutEventDetails],
-        "executionRedrivenEventDetails": Optional[ExecutionRedrivenEventDetails],
-        "mapStateStartedEventDetails": Optional[MapStateStartedEventDetails],
-        "mapIterationStartedEventDetails": Optional[MapIterationEventDetails],
-        "mapIterationSucceededEventDetails": Optional[MapIterationEventDetails],
-        "mapIterationFailedEventDetails": Optional[MapIterationEventDetails],
-        "mapIterationAbortedEventDetails": Optional[MapIterationEventDetails],
-        "lambdaFunctionFailedEventDetails": Optional[LambdaFunctionFailedEventDetails],
-        "lambdaFunctionScheduleFailedEventDetails": Optional[
-            LambdaFunctionScheduleFailedEventDetails
-        ],
-        "lambdaFunctionScheduledEventDetails": Optional[
-            LambdaFunctionScheduledEventDetails
-        ],
-        "lambdaFunctionStartFailedEventDetails": Optional[
-            LambdaFunctionStartFailedEventDetails
-        ],
-        "lambdaFunctionSucceededEventDetails": Optional[
-            LambdaFunctionSucceededEventDetails
-        ],
-        "lambdaFunctionTimedOutEventDetails": Optional[
-            LambdaFunctionTimedOutEventDetails
-        ],
-        "stateEnteredEventDetails": Optional[StateEnteredEventDetails],
-        "stateExitedEventDetails": Optional[StateExitedEventDetails],
-        "mapRunStartedEventDetails": Optional[MapRunStartedEventDetails],
-        "mapRunFailedEventDetails": Optional[MapRunFailedEventDetails],
-        "mapRunRedrivenEventDetails": Optional[MapRunRedrivenEventDetails],
-    },
-    total=False,
-)
-HistoryEventList = List[HistoryEvent]
+class HistoryEvent(TypedDict, total=False):
+    timestamp: Timestamp
+    type: HistoryEventType
+    id: EventId
+    previousEventId: Optional[EventId]
+    activityFailedEventDetails: Optional[ActivityFailedEventDetails]
+    activityScheduleFailedEventDetails: Optional[ActivityScheduleFailedEventDetails]
+    activityScheduledEventDetails: Optional[ActivityScheduledEventDetails]
+    activityStartedEventDetails: Optional[ActivityStartedEventDetails]
+    activitySucceededEventDetails: Optional[ActivitySucceededEventDetails]
+    activityTimedOutEventDetails: Optional[ActivityTimedOutEventDetails]
+    taskFailedEventDetails: Optional[TaskFailedEventDetails]
+    taskScheduledEventDetails: Optional[TaskScheduledEventDetails]
+    taskStartFailedEventDetails: Optional[TaskStartFailedEventDetails]
+    taskStartedEventDetails: Optional[TaskStartedEventDetails]
+    taskSubmitFailedEventDetails: Optional[TaskSubmitFailedEventDetails]
+    taskSubmittedEventDetails: Optional[TaskSubmittedEventDetails]
+    taskSucceededEventDetails: Optional[TaskSucceededEventDetails]
+    taskTimedOutEventDetails: Optional[TaskTimedOutEventDetails]
+    executionFailedEventDetails: Optional[ExecutionFailedEventDetails]
+    executionStartedEventDetails: Optional[ExecutionStartedEventDetails]
+    executionSucceededEventDetails: Optional[ExecutionSucceededEventDetails]
+    executionAbortedEventDetails: Optional[ExecutionAbortedEventDetails]
+    executionTimedOutEventDetails: Optional[ExecutionTimedOutEventDetails]
+    executionRedrivenEventDetails: Optional[ExecutionRedrivenEventDetails]
+    mapStateStartedEventDetails: Optional[MapStateStartedEventDetails]
+    mapIterationStartedEventDetails: Optional[MapIterationEventDetails]
+    mapIterationSucceededEventDetails: Optional[MapIterationEventDetails]
+    mapIterationFailedEventDetails: Optional[MapIterationEventDetails]
+    mapIterationAbortedEventDetails: Optional[MapIterationEventDetails]
+    lambdaFunctionFailedEventDetails: Optional[LambdaFunctionFailedEventDetails]
+    lambdaFunctionScheduleFailedEventDetails: Optional[
+        LambdaFunctionScheduleFailedEventDetails
+    ]
+    lambdaFunctionScheduledEventDetails: Optional[LambdaFunctionScheduledEventDetails]
+    lambdaFunctionStartFailedEventDetails: Optional[
+        LambdaFunctionStartFailedEventDetails
+    ]
+    lambdaFunctionSucceededEventDetails: Optional[LambdaFunctionSucceededEventDetails]
+    lambdaFunctionTimedOutEventDetails: Optional[LambdaFunctionTimedOutEventDetails]
+    stateEnteredEventDetails: Optional[StateEnteredEventDetails]
+    stateExitedEventDetails: Optional[StateExitedEventDetails]
+    mapRunStartedEventDetails: Optional[MapRunStartedEventDetails]
+    mapRunFailedEventDetails: Optional[MapRunFailedEventDetails]
+    mapRunRedrivenEventDetails: Optional[MapRunRedrivenEventDetails]
+    evaluationFailedEventDetails: Optional[EvaluationFailedEventDetails]
+
+
+HistoryEventList = list[HistoryEvent]
 
 
 class GetExecutionHistoryOutput(TypedDict, total=False):
@@ -898,6 +984,7 @@ class InspectionDataRequest(TypedDict, total=False):
 
 class InspectionData(TypedDict, total=False):
     input: Optional[SensitiveData]
+    afterArguments: Optional[SensitiveData]
     afterInputPath: Optional[SensitiveData]
     afterParameters: Optional[SensitiveData]
     result: Optional[SensitiveData]
@@ -905,27 +992,18 @@ class InspectionData(TypedDict, total=False):
     afterResultPath: Optional[SensitiveData]
     request: Optional[InspectionDataRequest]
     response: Optional[InspectionDataResponse]
-
-
-class ListActivitiesOutput(TypedDict, total=False):
-    activities: ActivityList
-    nextToken: Optional[PageToken]
-
-
-class ListExecutionsOutput(TypedDict, total=False):
-    executions: ExecutionList
-    nextToken: Optional[ListExecutionsPageToken]
+    variables: Optional[SensitiveData]
 
 
 class MapRunListItem(TypedDict, total=False):
-    executionArn: str
-    mapRunArn: str
-    stateMachineArn: str
+    executionArn: Arn
+    mapRunArn: LongArn
+    stateMachineArn: Arn
     startDate: Timestamp
     stopDate: Optional[Timestamp]
 
 
-MapRunList = List[MapRunListItem]
+MapRunList = list[MapRunListItem]
 
 
 class ListMapRunsOutput(TypedDict, total=False):
@@ -934,11 +1012,11 @@ class ListMapRunsOutput(TypedDict, total=False):
 
 
 class StateMachineAliasListItem(TypedDict, total=False):
-    stateMachineAliasArn: str
+    stateMachineAliasArn: LongArn
     creationDate: Timestamp
 
 
-StateMachineAliasList = List[StateMachineAliasListItem]
+StateMachineAliasList = list[StateMachineAliasListItem]
 
 
 class ListStateMachineAliasesOutput(TypedDict, total=False):
@@ -947,11 +1025,11 @@ class ListStateMachineAliasesOutput(TypedDict, total=False):
 
 
 class StateMachineVersionListItem(TypedDict, total=False):
-    stateMachineVersionArn: str
+    stateMachineVersionArn: LongArn
     creationDate: Timestamp
 
 
-StateMachineVersionList = List[StateMachineVersionListItem]
+StateMachineVersionList = list[StateMachineVersionListItem]
 
 
 class ListStateMachineVersionsOutput(TypedDict, total=False):
@@ -959,17 +1037,14 @@ class ListStateMachineVersionsOutput(TypedDict, total=False):
     nextToken: Optional[PageToken]
 
 
-StateMachineListItem = TypedDict(
-    "StateMachineListItem",
-    {
-        "stateMachineArn": str,
-        "name": Name,
-        "type": StateMachineType,
-        "creationDate": Timestamp,
-    },
-    total=False,
-)
-StateMachineList = List[StateMachineListItem]
+class StateMachineListItem(TypedDict, total=False):
+    stateMachineArn: Arn
+    name: Name
+    type: StateMachineType
+    creationDate: Timestamp
+
+
+StateMachineList = list[StateMachineListItem]
 
 
 class ListStateMachinesOutput(TypedDict, total=False):
@@ -983,7 +1058,7 @@ class ListTagsForResourceOutput(TypedDict, total=False):
 
 class PublishStateMachineVersionOutput(TypedDict, total=False):
     creationDate: Timestamp
-    stateMachineVersionArn: str
+    stateMachineVersionArn: Arn
 
 
 class RedriveExecutionOutput(TypedDict, total=False):
@@ -1003,13 +1078,13 @@ class SendTaskSuccessOutput(TypedDict, total=False):
 
 
 class StartExecutionOutput(TypedDict, total=False):
-    executionArn: str
+    executionArn: Arn
     startDate: Timestamp
 
 
 class StartSyncExecutionOutput(TypedDict, total=False):
-    executionArn: str
-    stateMachineArn: Optional[str]
+    executionArn: Arn
+    stateMachineArn: Optional[Arn]
     name: Optional[Name]
     startDate: Timestamp
     stopDate: Timestamp
@@ -1028,7 +1103,7 @@ class StopExecutionOutput(TypedDict, total=False):
     stopDate: Timestamp
 
 
-TagKeyList = List[TagKey]
+TagKeyList = list[TagKey]
 
 
 class TagResourceOutput(TypedDict, total=False):
@@ -1059,4 +1134,37 @@ class UpdateStateMachineAliasOutput(TypedDict, total=False):
 class UpdateStateMachineOutput(TypedDict, total=False):
     updateDate: Timestamp
     revisionId: Optional[RevisionId]
-    stateMachineVersionArn: Optional[str]
+    stateMachineVersionArn: Optional[Arn]
+
+
+class ValidateStateMachineDefinitionDiagnostic(TypedDict, total=False):
+    severity: ValidateStateMachineDefinitionSeverity
+    code: ValidateStateMachineDefinitionCode
+    message: ValidateStateMachineDefinitionMessage
+    location: Optional[ValidateStateMachineDefinitionLocation]
+
+
+ValidateStateMachineDefinitionDiagnosticList = list[
+    ValidateStateMachineDefinitionDiagnostic
+]
+
+
+class ValidateStateMachineDefinitionInput(TypedDict, total=False):
+    definition: Definition
+    type: Optional[StateMachineType]
+    severity: Optional[ValidateStateMachineDefinitionSeverity]
+    maxResults: Optional[ValidateStateMachineDefinitionMaxResult]
+
+
+class ValidateStateMachineDefinitionOutput(TypedDict, total=False):
+    result: ValidateStateMachineDefinitionResultCode
+    diagnostics: ValidateStateMachineDefinitionDiagnosticList
+    truncated: Optional[ValidateStateMachineDefinitionTruncated]
+
+
+class InvocationResponse(TypedDict, total=False):
+    Payload: Optional[Union[bytes, IO[bytes], Iterable[bytes]]]
+    StatusCode: Optional[int]
+    FunctionError: Optional[str]
+    LogResult: Optional[str]
+    ExecutedVersion: Optional[str]
